@@ -16,8 +16,7 @@ use std::iter::FromIterator;
 use syn::parse::Parser;
 use syn::Ident;
 
-use byteorder::{LittleEndian, ReadBytesExt};
-use if_rust_version::if_rust_version;
+use byteorder::{BigEndian, ByteOrder, LittleEndian, ReadBytesExt};
 use lazy_static::lazy_static;
 use quote::{quote, quote_spanned};
 use std::fs::File;
@@ -71,7 +70,7 @@ fn read_metadata(file: File) -> io::Result<HashMap<u64, Vec<MetaData>>> {
     let mut file = BufReader::new(file);
     let end = {
         const AUTO_KEYWORD: &[&[u8]] = &[&cpp_common::STRUCT_METADATA_MAGIC];
-        let aut = aho_corasick::AhoCorasick::new(AUTO_KEYWORD);
+        let aut = aho_corasick::AhoCorasick::new(AUTO_KEYWORD).unwrap();
         let found = aut.stream_find_iter(&mut file).next().expect(
             r#"
 -- rust-cpp fatal error --
@@ -87,11 +86,8 @@ NOTE: Double-check that the version of cpp_build and cpp_macros match"#,
     // version.
     let mut version_buf = [0; 16];
     file.read_exact(&mut version_buf)?;
-    let version = version_buf
-        .iter()
-        .take_while(|b| **b != b'\0')
-        .map(|b| *b as char)
-        .collect::<String>();
+    let version =
+        version_buf.iter().take_while(|b| **b != b'\0').map(|b| *b as char).collect::<String>();
 
     assert_eq!(
         version, VERSION,
@@ -100,19 +96,28 @@ NOTE: Double-check that the version of cpp_build and cpp_macros match"#,
 
 Version mismatch between cpp_macros and cpp_build for same crate."#
     );
+    let endianness_check = file.read_u64::<LittleEndian>()?;
+    if endianness_check == 0xffef {
+        read_metadata_rest::<LittleEndian>(file)
+    } else if endianness_check == 0xefff000000000000 {
+        read_metadata_rest::<BigEndian>(file)
+    } else {
+        panic!("Endianness check value matches neither little nor big endian.");
+    }
+}
 
-    let length = file.read_u64::<LittleEndian>()?;
+fn read_metadata_rest<E: ByteOrder>(
+    mut file: BufReader<File>,
+) -> io::Result<HashMap<u64, Vec<MetaData>>> {
+    let length = file.read_u64::<E>()?;
     let mut metadata = HashMap::new();
     for _ in 0..length {
-        let hash = file.read_u64::<LittleEndian>()?;
-        let size = file.read_u64::<LittleEndian>()? as usize;
-        let align = file.read_u64::<LittleEndian>()? as usize;
-        let flags = file.read_u64::<LittleEndian>()? as u64;
+        let hash = file.read_u64::<E>()?;
+        let size = file.read_u64::<E>()? as usize;
+        let align = file.read_u64::<E>()? as usize;
+        let flags = file.read_u64::<E>()?;
 
-        metadata
-            .entry(hash)
-            .or_insert_with(Vec::new)
-            .push(MetaData { size, align, flags });
+        metadata.entry(hash).or_insert_with(Vec::new).push(MetaData { size, align, flags });
     }
     Ok(metadata)
 }
@@ -168,11 +173,12 @@ fn extract_original_macro(input: &syn::DeriveInput) -> Option<proc_macro2::Token
         }
     }
     let mut f = Finder::default();
-    syn::visit::visit_derive_input(&mut f, &input);
+    syn::visit::visit_derive_input(&mut f, input);
     f.0
 }
 
 #[proc_macro_derive(__cpp_internal_closure)]
+#[allow(clippy::cognitive_complexity)]
 pub fn expand_internal(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
     assert_eq!(
         env!("CARGO_PKG_VERSION"),
@@ -236,22 +242,18 @@ NOTE: They cannot be generated by macro expansion."#})
             // Perform a compile time check that the sizes match. This should be
             // a no-op.
             if false {
+                #[allow(clippy::transmute_num_to_bytes)]
                 ::core::mem::transmute::<_, [u8; #size]>(
                     ::core::ptr::read(&$#mac_name));
             }
 
             // NOTE: Both of these calls should be dead code in opt builds.
-            assert!(::core::mem::size_of_val(&$#mac_name) == #size,
-                    #sizeof_msg);
+            #[allow(clippy::size_of_ref)] { assert!(::core::mem::size_of_val(&$#mac_name) == #size, #sizeof_msg); };
             assert!(::core::mem::align_of_val(&$#mac_name) == #align,
                     #alignof_msg);
         };
 
-        let mb_mut = if capture.mutable {
-            quote_spanned!(span=> mut)
-        } else {
-            quote!()
-        };
+        let mb_mut = if capture.mutable { quote_spanned!(span=> mut) } else { quote!() };
         let ptr = if capture.mutable {
             quote_spanned!(span=> *mut)
         } else {
@@ -272,11 +274,7 @@ NOTE: They cannot be generated by macro expansion."#})
 
     let extern_name = closure.sig.extern_name();
     let ret_ty = &closure.sig.ret;
-    let MetaData {
-        size: ret_size,
-        align: ret_align,
-        flags,
-    } = size_data[0];
+    let MetaData { size: ret_size, align: ret_align, flags } = size_data[0];
     let is_void = closure.sig.cpp == "void";
 
     let decl = if is_void {
@@ -293,7 +291,7 @@ NOTE: They cannot be generated by macro expansion."#})
         assert!(ret_size == 0, "`void` should have a size of 0!");
         quote! {
             #extern_name(#(#call_args),*);
-            #[cfg_attr(feature = "cargo-clippy", allow(useless_transmute))]
+            #[allow(clippy::useless_transmute)]
             ::core::mem::transmute::<(), (#ret_ty)>(())
         }
     } else {
@@ -304,26 +302,19 @@ NOTE: They cannot be generated by macro expansion."#})
                 const _assert_align: [(); #ret_align] = [(); ::core::mem::align_of::<#ret_ty>()];
             }
         };
-        if_rust_version!(>= 1.36 { quote!(
+        quote!(
             #assert_size
             let mut result = ::core::mem::MaybeUninit::<#ret_ty>::uninit();
             #extern_name(#(#call_args,)* result.as_mut_ptr());
             result.assume_init()
-        )} else { quote!(
-            #assert_size
-            let mut result: #ret_ty = ::core::mem::uninitialized();
-            #extern_name(#(#call_args,)* &mut result);
-            result
-        )})
+        )
     };
 
     let input = proc_macro2::TokenStream::from_iter([closure.body].iter().cloned());
     let rust_invocations = find_all_rust_macro.parse2(input).expect("rust! macro");
     let init_callbacks = if !rust_invocations.is_empty() {
-        let rust_cpp_callbacks = Ident::new(
-            &format!("rust_cpp_callbacks{}", *FILE_HASH),
-            Span::call_site(),
-        );
+        let rust_cpp_callbacks =
+            Ident::new(&format!("rust_cpp_callbacks{}", *FILE_HASH), Span::call_site());
         let offset = (flags >> 32) as isize;
         let callbacks: Vec<Ident> = rust_invocations.iter().map(|x| x.id.clone()).collect();
         quote! {
@@ -471,15 +462,11 @@ NOTE: They cannot be generated by macro expansion."#})
 
     if size_data[0].has_flag(flags::IS_COPY_CONSTRUCTIBLE) {
         if !size_data[0].has_flag(flags::IS_TRIVIALLY_COPYABLE) && !class.derives("Copy") {
-            let call_construct = if_rust_version!(>= 1.36 { quote!(
+            let call_construct = quote!(
                 let mut result = ::core::mem::MaybeUninit::<Self>::uninit();
                 #copyctr_name(& *self, result.as_mut_ptr());
                 result.assume_init()
-            )} else { quote!(
-                let mut result : Self = ::core::mem::uninitialized();
-                #copyctr_name(& *self, &mut result);
-                result
-            )});
+            );
             result = quote! { #result
                 impl ::core::clone::Clone for #class_name {
                     fn clone(&self) -> Self {
@@ -503,15 +490,11 @@ NOTE: They cannot be generated by macro expansion."#})
     }
 
     if size_data[0].has_flag(flags::IS_DEFAULT_CONSTRUCTIBLE) {
-        let call_construct = if_rust_version!(>= 1.36 { quote!(
+        let call_construct = quote!(
             let mut result = ::core::mem::MaybeUninit::<Self>::uninit();
             #defaultctr_name(result.as_mut_ptr());
             result.assume_init()
-        )} else { quote!(
-            let mut result : Self = ::core::mem::uninitialized();
-            #defaultctr_name(&mut result);
-            result
-        )});
+        );
         result = quote! { #result
             impl ::core::default::Default for #class_name {
                 fn default() -> Self {
